@@ -1,5 +1,41 @@
+import pathlib
 from collections import OrderedDict
-from typing import Any, Dict, List
+from typing import Any, Iterable, List, MutableMapping, Optional, Tuple, Union
+
+from typing_extensions import TypedDict
+
+# Type
+Questions = Iterable[MutableMapping[str, Any]]
+
+
+class CzSettings(TypedDict, total=False):
+    bump_pattern: str
+    bump_map: "OrderedDict[str, str]"
+    change_type_order: List[str]
+
+    questions: Questions
+    example: Optional[str]
+    schema_pattern: Optional[str]
+    schema: Optional[str]
+    info_path: Union[str, pathlib.Path]
+    info: str
+    message_template: str
+
+
+class Settings(TypedDict, total=False):
+    name: str
+    version: Optional[str]
+    version_files: List[str]
+    tag_format: Optional[str]
+    bump_message: Optional[str]
+    changelog_file: str
+    changelog_incremental: bool
+    changelog_start_rev: Optional[str]
+    update_changelog_on_bump: bool
+    use_shortcuts: bool
+    style: Optional[List[Tuple[str, str]]]
+    customize: CzSettings
+
 
 name: str = "cz_conventional_commits"
 config_files: List[str] = [
@@ -11,7 +47,7 @@ config_files: List[str] = [
     "cz.yaml",
 ]
 
-DEFAULT_SETTINGS: Dict[str, Any] = {
+DEFAULT_SETTINGS: Settings = {
     "name": "cz_conventional_commits",
     "version": None,
     "version_files": [],
@@ -39,9 +75,10 @@ bump_map = OrderedDict(
         (r"^perf", PATCH),
     )
 )
+change_type_order = ["BREAKING CHANGE", "feat", "fix", "refactor", "perf"]
+
 bump_message = "bump: version $current_version → $new_version"
 
-change_type_order = ["BREAKING CHANGE", "feat", "fix", "refactor", "perf"]
 
 commit_parser = r"^(?P<change_type>feat|fix|refactor|perf|BREAKING CHANGE)(?:\((?P<scope>[^()\r\n]*)\)|\()?(?P<breaking>!)?:\s(?P<message>.*)?"  # noqa
 version_parser = r"(?P<version>([0-9]+)\.([0-9]+)\.([0-9]+)(?:-([0-9A-Za-z-]+(?:\.[0-9A-Za-z-]+)*))?(?:\+[0-9A-Za-z-]+)?(\w+)?)"
